from colored_custom_logger import CustomLogger

logger = CustomLogger.get_logger("basic_example")

logger.debug("This is a debug message")
logger.info("This is an info message")
logger.warning("This is a warning message")
logger.error("This is an error message")
logger.critical("This is a critical message")
